function newImage = fuzzy(image,nsize)
% newImage = fuzzy(image,nsize)
% Returns a blurry version of the input image (a 2D 8-bit (uint8) matrix), 
% where the intensity at each image location is replaced by an average of 
% its neighbors within an area that covers nsize rows and columns on both 
% sides of each location

% convert to double to enable floating-point calculation of average
image = double(image); 

% create a new image of the same size
[rows,cols] = size(image);
newImage = zeros(rows,cols);

% scale factor used to divide the sum of intensities in each neighborhood 
% by the number of pixels in the neighborhood
scale = 1.0/((2*nsize+1)^2);  

% compute average intensity at each location, omitting a border of nsize 
% pixels from the computation
for row = nsize+1:rows-nsize
    for col = nsize+1:cols-nsize
        newImage(row,col) = ...
            scale*sum(sum(image(row-nsize:row+nsize,col-nsize:col+nsize)));
    end
end
% return an 8-bit image
newImage = uint8(newImage);
